@@ -54,11 +54,13 @@ disambiguation, and in some cases warns.
 import os
 import sys
 import gzip
+import dateutil.parser  # For parsing date strings
 from distutils.version import LooseVersion
 
 from vcstools.vcs_base import VcsClientBase, VcsError
 from vcstools.common import sanitized, normalized_rel_path, run_shell_command
 
+
 def _git_diff_path_submodule_change(diff, rel_path_prefix):
     """
     Parses git diff result and changes the filename prefixes.
@@ -210,6 +212,7 @@ class GitClient(VcsClientBase):
             return False
 
         if force_fetch:
+            need_to_fetch = False
             self._do_fetch(True)
 
         # are we on any branch?
@@ -332,6 +335,34 @@ class GitClient(VcsClientBase):
                 response += _git_diff_path_submodule_change(output, rel_path)
         return response
 
+    def get_log(self, relpath=None, limit=None):
+        response = []
+
+        if relpath == None:
+            relpath = ''
+
+        if self.path_exists() and os.path.exists(os.path.join(self._path, relpath)):
+            # Get the log
+            limit_cmd = (("-n %d" % (int(limit))) if limit else "")
+
+            GIT_COMMIT_FIELDS = ['id', 'author', 'email', 'date', 'message']
+            GIT_LOG_FORMAT = '%x1f'.join(['%H', '%an', '%ae', '%ad', '%s']) + '%x1e'
+
+            command = "git --work-tree=%s log --format=\"%s\" %s %s " % (self._path, GIT_LOG_FORMAT, limit_cmd, sanitized(relpath))
+            return_code, response, stderr = run_shell_command(command, shell=True, cwd=self._path)
+
+            if return_code == 0:
+                # Parse response
+                response = response.strip('\n\x1e').split("\x1e")
+                response = [row.strip().split("\x1f") for row in response]
+                response = [dict(zip(GIT_COMMIT_FIELDS, row)) for row in response]
+
+            # Parse dates
+            for entry in response:
+                entry['date'] = dateutil.parser.parse(entry['date'])
+
+        return response
+
     def get_status(self, basepath=None, untracked=False):
         response = None
         if basepath is None:
@@ -548,15 +579,17 @@ class GitClient(VcsClientBase):
         result, _, _ = run_shell_command(cmd, shell=True, cwd=self._path)
         if result:
             return False
-        # Gzip the tar file
-        with open(basepath + '.tar', 'rb') as tar_file:
-            gzip_file = gzip.open(basepath + '.tar.gz', 'wb')
-            try:
-                gzip_file.writelines(tar_file)
-            finally:
-                gzip_file.close()
-        # Clean up
-        os.remove(basepath + '.tar')
+        try:
+            # Gzip the tar file
+            with open(basepath + '.tar', 'rb') as tar_file:
+                gzip_file = gzip.open(basepath + '.tar.gz', 'wb')
+                try:
+                    gzip_file.writelines(tar_file)
+                finally:
+                    gzip_file.close()
+        finally:
+            # Clean up
+            os.remove(basepath + '.tar')
         return True
 
     def _do_fetch(self, with_tags=False):
